Crate slut

Crate slut 

Modules

complex
dimension
si
tensor
units

Macros

assert_approx_eq
assert_dimension
Asserts that the type of $value is a Tensor with the expected dimension type. Returns $value on success so that the macro can be used inline.
base_unit_dim
cvec
dim_div
dim_inv
dim_mul
dless
dot
impl_unit
inner_product
ip
unit_div
unit_inv
unit_mul