macro_rules! assert_dimension {
($value:expr, $expected:ty) => { ... };
}Expand description
Asserts that the type of $value is a Tensor with the expected dimension type.
Returns $value on success so that the macro can be used inline.
macro_rules! assert_dimension {
($value:expr, $expected:ty) => { ... };
}Asserts that the type of $value is a Tensor with the expected dimension type.
Returns $value on success so that the macro can be used inline.